@@ -8,6 +8,10 @@ test_that("list_automatic_tape_creation_policies", {
   expect_error(svc$list_automatic_tape_creation_policies(), NA)
 })
 
+test_that("list_cache_reports", {
+  expect_error(svc$list_cache_reports(), NA)
+})
+
 test_that("list_file_shares", {
   expect_error(svc$list_file_shares(), NA)
 })
